@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::InitTarget;
 
-our $DATE = '2017-08-04'; # DATE
-our $VERSION = '0.012'; # VERSION
+our $DATE = '2018-12-20'; # DATE
+our $VERSION = '0.013'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,7 +53,7 @@ Bencher::Scenario::LogGer::InitTarget - Benchmark init_target()
 
 =head1 VERSION
 
-This document describes version 0.012 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-04.
+This document describes version 0.013 of Bencher::Scenario::LogGer::InitTarget (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/YjnhbWBOx_'); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("File", path=>'/tmp/5fZO3OAq1x'); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -119,7 +119,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/YjnhbWBOx_'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{}, File=>{conf=>{path=>'/tmp/5fZO3OAq1x'}}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -127,7 +127,7 @@ Code template:
 
 Code template:
 
- use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/YjnhbWBOx_'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
+ use Log::ger (); local %Log::ger::Global_Hooks = %Log::ger::Default_Hooks; use Log::ger::Output; Log::ger::Output->set("Composite", outputs=>{Screen=>{layout=>[Pattern=>{format=>"[%d] %m"}]}, File=>{conf=>{path=>'/tmp/5fZO3OAq1x'}, layout=>[Pattern=>{format=>"[%d] [%P] %m"}]}}); for(1..1000) { Log::ger::init_target(package => "main") }
 
 
 
@@ -135,7 +135,7 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.2 >>, OS kernel: I<< Linux version 4.8.0-53-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::InitTarget >>):
 
@@ -143,13 +143,13 @@ Benchmark with default options (C<< bencher -m LogGer::InitTarget >>):
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
  | participant                                        | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
- | with LGO:Composite (Screen+File & pattern layouts) |      2.76 |       363 |        1   | 0.00019 |       8 |
- | default                                            |      2.8  |       350 |        1   | 0.00074 |       8 |
- | with LGO:Composite (Screen+File)                   |      3    |       340 |        1.1 | 0.0008  |       7 |
- | with LGO:Composite (Screen)                        |      4    |       250 |        1.4 | 0.00074 |       7 |
- | with LGO:File                                      |      5    |       200 |        2   | 0.0025  |       7 |
- | with LGO:Composite (0 outputs)                     |      7.3  |       140 |        2.7 | 0.00028 |       7 |
- | with LGO:Screen                                    |      7.4  |       140 |        2.7 | 0.00021 |       8 |
+ | with LGO:Composite (Screen+File & pattern layouts) |      2.8  |       360 |       1    | 0.0015  |       7 |
+ | default                                            |      2.8  |       350 |       1    | 0.0005  |       7 |
+ | with LGO:Composite (Screen+File)                   |      2.92 |       343 |       1.05 | 0.00032 |       7 |
+ | with LGO:Composite (Screen)                        |      4    |       250 |       1.4  | 0.00042 |       7 |
+ | with LGO:File                                      |      5.32 |       188 |       1.92 | 0.00016 |       7 |
+ | with LGO:Screen                                    |      7.4  |       130 |       2.7  | 0.0003  |       7 |
+ | with LGO:Composite (0 outputs)                     |      7.4  |       130 |       2.7  | 0.00015 |       7 |
  +----------------------------------------------------+-----------+-----------+------------+---------+---------+
 
 
@@ -177,7 +177,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
