@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Overhead;
 
-our $DATE = '2017-08-04'; # DATE
-our $VERSION = '0.012'; # VERSION
+our $DATE = '2018-12-20'; # DATE
+our $VERSION = '0.013'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,6 +20,8 @@ our $scenario = {
         'Log::ger::Output' => {version=>'0.005'},
         'Log::ger::Layout::Pattern' => {version=>'0'},
         'Log::Contextual' => {version=>'0'},
+        'Log::Dispatch' => {version=>'0'},
+        'Log::Dispatch::Null' => {version=>'0'},
         'Log::Log4perl' => {version=>'0'},
         'Log::Log4perl::Tiny' => {version=>'0'},
         'Log::Dispatchouli' => {version=>'0'},
@@ -45,6 +47,9 @@ our $scenario = {
 
         {code_template=>'use Log::Log4perl::Tiny;'},
 
+        {code_template=>'use Log::Dispatch;'},
+        {code_template=>'use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Null", min_level=>"warn"] ])', tags=>['output']},
+
         {code_template=>'use Log::Dispatchouli;'},
 
         {code_template=>'use Log::ger::Output::Screen;', tags=>['output']},
@@ -72,7 +77,7 @@ Bencher::Scenario::LogGer::Overhead - Measure startup overhead of various codes
 
 =head1 VERSION
 
-This document describes version 0.012 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-08-04.
+This document describes version 0.013 of Bencher::Scenario::LogGer::Overhead (from Perl distribution Bencher-Scenarios-LogGer), released on 2018-12-20.
 
 =head1 SYNOPSIS
 
@@ -90,10 +95,14 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::Any> 1.049
+L<Log::Any> 1.707
 
 L<Log::Contextual> 0.007001
 
+L<Log::Dispatch> 2.65
+
+L<Log::Dispatch::Null> 2.65
+
 L<Log::Dispatchouli> 2.015
 
 L<Log::Log4perl> 1.49
@@ -102,7 +111,7 @@ L<Log::Log4perl::Tiny> 1.4.0
 
 L<Log::ger> 0.023
 
-L<Log::ger::App> 0.003
+L<Log::ger::App> 0.009
 
 L<Log::ger::Layout::Pattern> 0.001
 
@@ -224,6 +233,22 @@ Code template:
 
 
 
+=item * use Log::Dispatch; (perl_code)
+
+Code template:
+
+ use Log::Dispatch;
+
+
+
+=item * use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu (perl_code) [output]
+
+Code template:
+
+ use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Null", min_level=>"warn"] ])
+
+
+
 =item * use Log::Dispatchouli; (perl_code)
 
 Code template:
@@ -252,32 +277,34 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.2 >>, OS kernel: I<< Linux version 4.8.0-53-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::Overhead >>):
 
  #table1#
- +----------------------------------------------+------------------------------+--------------------+----------------+-----------+-------------------------+------------+-----------+---------+
- | participant                                  | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | code_overhead_time (ms) | vs_slowest |  errors   | samples |
- +----------------------------------------------+------------------------------+--------------------+----------------+-----------+-------------------------+------------+-----------+---------+
- | use Log::Dispatchouli;                       | 568                          | 4                  | 20             |     130   |                   124   |        1   |   0.00023 |      20 |
- | use Log::Contextual qw(:log);                | 572                          | 4                  | 20             |      94   |                    88   |        1.3 |   0.00017 |      20 |
- | use Log::Log4perl;                           | 568                          | 3.9                | 20             |      45   |                    39   |        2.8 |   0.00013 |      20 |
- | use Log::ger::App; use Log::ger;             | 572                          | 3.9                | 20             |      27   |                    21   |        4.6 | 7.9e-05   |      20 |
- | use Log::Log4perl::Tiny;                     | 572                          | 4                  | 20             |      25   |                    19   |        5.1 | 3.6e-05   |      20 |
- | use Log::ger::App;                           | 572                          | 3.9                | 20             |      19   |                    13   |        6.7 | 4.3e-05   |      21 |
- | use Log::ger::Like::Log4perl;                | 572                          | 4                  | 20             |      18   |                    12   |        6.9 | 6.1e-05   |      20 |
- | use Log::Any q($log);                        | 572                          | 4                  | 20             |      18   |                    12   |        7.1 | 7.3e-05   |      22 |
- | use Log::Any;                                | 572                          | 4                  | 20             |      17   |                    11   |        7.6 | 6.4e-05   |      20 |
- | use Log::ger::Output::Screen;                | 568                          | 4                  | 20             |      13   |                     7   |        9.5 | 3.9e-05   |      20 |
- | use Log::ger::Output::Composite;             | 572                          | 3.9                | 20             |      10   |                     4   |       13   |   2e-05   |      20 |
- | use Log::ger::Plugin::OptAway; use Log::ger; | 572                          | 4                  | 20             |       9.9 |                     3.9 |       13   | 2.5e-05   |      20 |
- | use Log::ger::Like::LogAny;                  | 568                          | 3.9                | 20             |       7.4 |                     1.4 |       17   |   3e-05   |      20 |
- | use Log::ger; Log::ger->get_logger;          | 572                          | 4                  | 20             |       7   |                     1   |       20   | 7.2e-05   |      20 |
- | use Log::ger;                                | 572                          | 4                  | 20             |       7   |                     1   |       20   | 7.5e-05   |      20 |
- | use Log::ger ();                             | 568                          | 4                  | 20             |       7   |                     1   |       18   | 1.7e-05   |      20 |
- | perl -e1 (baseline)                          | 568                          | 4                  | 20             |       6   |                     0   |       20   | 6.5e-05   |      20 |
- +----------------------------------------------+------------------------------+--------------------+----------------+-----------+-------------------------+------------+-----------+---------+
+ +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
+ | participant                                                      | time (ms) | code_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
+ | use Log::Dispatchouli;                                           |     103   |      97.4               |       1    | 8.2e-05   |      20 |
+ | use Log::Dispatch; my $null = Log::Dispatch->new(outputs=>[ ["Nu |     100   |      94.4               |       1    |   0.00011 |      20 |
+ | use Log::Dispatch;                                               |      95.2 |      89.6               |       1.08 | 7.4e-05   |      20 |
+ | use Log::Contextual qw(:log);                                    |      77   |      71.4               |       1.3  |   0.00015 |      20 |
+ | use Log::Log4perl;                                               |      37.4 |      31.8               |       2.76 | 2.6e-05   |      20 |
+ | use Log::ger::App; use Log::ger;                                 |      20   |      14.4               |       4    |   0.00025 |      20 |
+ | use Log::Log4perl::Tiny;                                         |      21   |      15.4               |       4.9  | 3.1e-05   |      20 |
+ | use Log::ger::App;                                               |      20   |      14.4               |       6    |   0.0002  |      20 |
+ | use Log::ger::Like::Log4perl;                                    |      16   |      10.4               |       6.3  |   4e-05   |      20 |
+ | use Log::Any q($log);                                            |      15   |       9.4               |       6.9  | 9.4e-05   |      20 |
+ | use Log::Any;                                                    |      14   |       8.4               |       7.2  | 3.3e-05   |      21 |
+ | use Log::ger::Output::Screen;                                    |      13   |       7.4               |       8.3  |   0.00012 |      20 |
+ | use Log::ger::Output::Composite;                                 |      10   |       4.4               |      10    |   0.00015 |      20 |
+ | use Log::ger::Plugin::OptAway; use Log::ger;                     |       8.8 |       3.2               |      12    | 2.8e-05   |      22 |
+ | use Log::ger ();                                                 |       6.5 |       0.9               |      16    |   3e-05   |      20 |
+ | use Log::ger; Log::ger->get_logger;                              |       6   |       0.4               |      20    | 7.4e-05   |      20 |
+ | use Log::ger::Like::LogAny;                                      |       6.4 |       0.800000000000001 |      16    | 1.5e-05   |      21 |
+ | use Log::ger;                                                    |       6.3 |       0.7               |      16    | 3.6e-05   |      20 |
+ | perl -e1 (baseline)                                              |       5.6 |       0                 |      18    | 3.6e-05   |      20 |
+ +------------------------------------------------------------------+-----------+-------------------------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -304,7 +331,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
