@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::InitTarget;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -8,31 +8,31 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00019,
+        errors => 0.0015,
         participant => "with LGO:Composite (Screen+File & pattern layouts)",
-        rate => 2.76,
-        samples => 8,
-        time => 363,
+        rate => 2.8,
+        samples => 7,
+        time => 360,
         vs_slowest => 1,
       },
       {
-        errors => 0.00074,
+        errors => 0.0005,
         participant => "default",
         rate => 2.8,
-        samples => 8,
+        samples => 7,
         time => 350,
         vs_slowest => 1,
       },
       {
-        errors => 0.0008,
+        errors => 0.00032,
         participant => "with LGO:Composite (Screen+File)",
-        rate => 3,
+        rate => 2.92,
         samples => 7,
-        time => 340,
-        vs_slowest => 1.1,
+        time => 343,
+        vs_slowest => 1.05,
       },
       {
-        errors => 0.00074,
+        errors => 0.00042,
         participant => "with LGO:Composite (Screen)",
         rate => 4,
         samples => 7,
@@ -40,27 +40,27 @@ our $results = [
         vs_slowest => 1.4,
       },
       {
-        errors => 0.0025,
+        errors => 0.00016,
         participant => "with LGO:File",
-        rate => 5,
+        rate => 5.32,
         samples => 7,
-        time => 200,
-        vs_slowest => 2,
+        time => 188,
+        vs_slowest => 1.92,
       },
       {
-        errors => 0.00028,
-        participant => "with LGO:Composite (0 outputs)",
-        rate => 7.3,
+        errors => 0.0003,
+        participant => "with LGO:Screen",
+        rate => 7.4,
         samples => 7,
-        time => 140,
+        time => 130,
         vs_slowest => 2.7,
       },
       {
-        errors => 0.00021,
-        participant => "with LGO:Screen",
+        errors => 0.00015,
+        participant => "with LGO:Composite (0 outputs)",
         rate => 7.4,
-        samples => 8,
-        time => 140,
+        samples => 7,
+        time => 130,
         vs_slowest => 2.7,
       },
     ],
@@ -145,18 +145,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -165,7 +165,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3214.675,
+                                              speed                        => 3222.607,
                                               stepping                     => 7,
                                             },
                                             {
@@ -240,18 +240,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -260,7 +260,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3244.101,
+                                              speed                        => 3303.399,
                                               stepping                     => 7,
                                             },
                                             {
@@ -335,18 +335,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -355,7 +355,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "3252.820",
+                                              speed                        => 3264.801,
                                               stepping                     => 7,
                                             },
                                             {
@@ -430,18 +430,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -450,14 +450,14 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3213.949,
+                                              speed                        => 3289.019,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 16.037036895752,
+      "func.elapsed_time"              => 15.5287089347839,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => "1.040",
+                                            "__PACKAGE__" => 1.041,
                                             "Bencher::Scenario::LogGer::InitTarget" => undef,
                                             "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
@@ -468,24 +468,24 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 6]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -495,9 +495,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1499942633,
       "func.scenario_module_sha1sum"   => "04369046d22a6d1e2ce7ae2fc07be5e54ddf2e04",
       "func.scenario_module_sha256sum" => "733fb6fa020e5d8133f3addf99e97085c8878254367f5d714a603650c8820b2f",
-      "func.time_end"                  => 1501853030.24724,
+      "func.time_end"                  => 1545303580.45636,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501853014.2102,
+      "func.time_start"                => 1545303564.92765,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
