@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::LayoutStartup;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -8,44 +8,44 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00015,
+        errors => 3e-05,
         participant => "load-YAML",
-        rate => 55,
-        samples => 21,
-        time => 18,
+        rate => 68,
+        samples => 20,
+        time => 15,
         vs_slowest => 1,
       },
       {
-        errors => 6.6e-05,
+        errors => 3.4e-05,
         participant => "load-JSON",
-        rate => 59,
+        rate => 69,
         samples => 20,
-        time => 17,
-        vs_slowest => 1.1,
+        time => 14,
+        vs_slowest => 1,
       },
       {
-        errors => 0.00011,
+        errors => 3.8e-05,
         participant => "load-LTSV",
-        rate => 61,
+        rate => 71,
         samples => 20,
-        time => 16,
-        vs_slowest => 1.1,
+        time => 14,
+        vs_slowest => 1,
       },
       {
-        errors => 0.00012,
+        errors => 1.9e-05,
         participant => "load-Pattern",
-        rate => 61,
+        rate => 71,
         samples => 20,
-        time => 16,
-        vs_slowest => 1.1,
+        time => 14,
+        vs_slowest => 1,
       },
       {
-        errors => 4.6e-05,
+        errors => 2.5e-05,
         participant => "baseline",
-        rate => 190,
-        samples => 20,
-        time => 5.3,
-        vs_slowest => 3.4,
+        rate => 180,
+        samples => 21,
+        time => 5.6,
+        vs_slowest => 2.6,
       },
     ],
     {
@@ -129,18 +129,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -149,7 +149,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "3230.660",
+                                              speed                        => 3285.803,
                                               stepping                     => 7,
                                             },
                                             {
@@ -224,18 +224,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -244,7 +244,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3216.976,
+                                              speed                        => 3282.775,
                                               stepping                     => 7,
                                             },
                                             {
@@ -319,18 +319,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -339,7 +339,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3205.714,
+                                              speed                        => 3267.828,
                                               stepping                     => 7,
                                             },
                                             {
@@ -414,18 +414,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -434,14 +434,14 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3204.261,
+                                              speed                        => 3283.154,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.96169209480286,
+      "func.elapsed_time"              => 1.66708588600159,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                              => "1.040",
+                                            "__PACKAGE__"                              => 1.041,
                                             "Bencher::Scenario::LogGer::LayoutStartup" => undef,
                                             "Benchmark::Dumb"                          => 0.111,
                                             "Devel::Platform::Info"                    => 0.16,
@@ -456,24 +456,24 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 4]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -483,9 +483,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1499219367,
       "func.scenario_module_sha1sum"   => "d7c9b98e30622206fbbf957960dbedb4df39dfb0",
       "func.scenario_module_sha256sum" => "51f457d0cc5b3373aca89a08fd42501b541acbe2ad3121a37756a35e8c3e2cdb",
-      "func.time_end"                  => 1501853032.50487,
+      "func.time_end"                  => 1545303582.45058,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501853030.54318,
+      "func.time_start"                => 1545303580.7835,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
