@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -8,132 +8,140 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0055,
-        participant => "Log::Contextual+Log4perl",
-        rate => 0.17,
+        errors => 0.0027,
+        participant => "Log::Dispatch::Null-100k_debug",
+        rate => 0.6,
         samples => 6,
-        time => 5.89,
+        time => 1.7,
         vs_slowest => 1,
       },
       {
-        errors => 0.001,
-        participant => "Log::Contextual+SimpleLogger",
-        rate => 0.176,
+        errors => 0.0018,
+        participant => "Log::Contextual+Log4perl-100k_trace",
+        rate => 1.5,
         samples => 6,
-        time => 5.7,
-        vs_slowest => 1.03,
+        time => 0.65,
+        vs_slowest => 2.6,
       },
       {
-        errors => 0.0022,
-        participant => "Log::Log4perl::Tiny-1mil_trace",
-        rate => 0.84,
+        errors => 0.0035,
+        participant => "Log::Contextual+SimpleLogger-100k_trace",
+        rate => 1.6,
         samples => 6,
-        time => 1.2,
-        vs_slowest => 5,
-      },
-      {
-        errors => 0.0037,
-        participant => "Log::Dispatchouli",
-        rate => 1.2,
-        samples => 6,
-        time => 0.84,
-        vs_slowest => 7,
+        time => 0.64,
+        vs_slowest => 2.6,
       },
       {
         errors => 0.00084,
-        participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 1.6,
-        samples => 6,
-        time => 0.61,
-        vs_slowest => 9.7,
+        participant => "Log::Dispatchouli-100k_debug",
+        rate => 4.7,
+        samples => 7,
+        time => 0.21,
+        vs_slowest => 7.9,
       },
       {
-        errors => 0.00058,
-        participant => "Log::Fast-1mil_is_debug",
-        rate => 2.1,
-        samples => 6,
-        time => 0.48,
+        errors => 0.00037,
+        participant => "Log::Log4perl::Tiny-100k_trace",
+        rate => 7.3,
+        samples => 8,
+        time => 0.14,
         vs_slowest => 12,
       },
       {
-        errors => 0.0018,
-        participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 2.4,
-        samples => 6,
-        time => 0.41,
-        vs_slowest => 14,
+        errors => 0.00018,
+        participant => "Log::Any-null_adapter-100k_log_trace",
+        rate => 12,
+        samples => 8,
+        time => 0.082,
+        vs_slowest => 21,
       },
       {
-        errors => 0.0019,
-        participant => "Log::Any-null_adapter-1mil_is_trace",
-        rate => 2.5,
-        samples => 6,
-        time => 0.41,
-        vs_slowest => 14,
-      },
-      {
-        errors => 0.00064,
-        participant => "Log::Log4perl-easy-1mil_trace",
-        rate => 3.1,
-        samples => 6,
-        time => 0.32,
-        vs_slowest => 18,
-      },
-      {
-        errors => 0.00038,
-        participant => "Log::Fast-1mil_DEBUG",
-        rate => 6.3,
-        samples => 6,
-        time => 0.16,
-        vs_slowest => 37,
-      },
-      {
-        errors => 0.00031,
-        participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 6.4,
-        samples => 6,
-        time => 0.16,
-        vs_slowest => 38,
-      },
-      {
-        errors => 9.3e-05,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
-        rate => 9.06,
-        samples => 6,
-        time => 0.11,
-        vs_slowest => 53.4,
-      },
-      {
-        errors => 8.4e-05,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
-        rate => 9.12,
-        samples => 6,
-        time => 0.11,
-        vs_slowest => 53.7,
-      },
-      {
-        errors => 0.00026,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 9.3,
-        samples => 9,
-        time => 0.11,
-        vs_slowest => 55,
-      },
-      {
-        errors => 0.00013,
-        participant => "Log::ger-1mil_log_trace",
+        errors => 0.00093,
+        participant => "Log::Fast-100k_is_debug",
         rate => 10,
         samples => 6,
-        time => 0.098,
-        vs_slowest => 60,
+        time => 0.08,
+        vs_slowest => 20,
       },
       {
-        errors => 9e-05,
-        participant => "Log::ger+LGP:OptAway-1mil_log_trace",
-        rate => 22,
+        errors => 2.4e-05,
+        participant => "Log::Log4perl-easy-100k_trace",
+        rate => 15.1,
         samples => 6,
-        time => 0.046,
-        vs_slowest => 130,
+        time => 0.0661,
+        vs_slowest => 25.4,
+      },
+      {
+        errors => 0.00018,
+        participant => "Log::Any-no_adapter-100k_is_trace",
+        rate => 17,
+        samples => 6,
+        time => 0.057,
+        vs_slowest => 29,
+      },
+      {
+        errors => 7.5e-05,
+        participant => "Log::Any-null_adapter-100k_is_trace",
+        rate => 19,
+        samples => 6,
+        time => 0.054,
+        vs_slowest => 31,
+      },
+      {
+        errors => 0.0008,
+        participant => "Log::Fast-100k_DEBUG",
+        rate => 20,
+        samples => 9,
+        time => 0.05,
+        vs_slowest => 40,
+      },
+      {
+        errors => 0.00027,
+        participant => "Log::Any-no_adapter-100k_log_trace",
+        rate => 32,
+        samples => 7,
+        time => 0.031,
+        vs_slowest => 53,
+      },
+      {
+        errors => 7.6e-05,
+        participant => "Log::ger+LGP:OptAway-100k_log_trace",
+        rate => 41,
+        samples => 8,
+        time => 0.024,
+        vs_slowest => 69,
+      },
+      {
+        errors => 0.00044,
+        participant => "Log::ger+LGP:MutilevelLog-100k_log_trace",
+        rate => 40,
+        samples => 7,
+        time => 0.02,
+        vs_slowest => 70,
+      },
+      {
+        errors => 0.00017,
+        participant => "Log::ger+LGP:MutilevelLog-100k_log_6",
+        rate => 44,
+        samples => 6,
+        time => 0.022,
+        vs_slowest => 75,
+      },
+      {
+        errors => 0.00014,
+        participant => "Log::ger-100k_log_is_trace",
+        rate => 61,
+        samples => 7,
+        time => 0.016,
+        vs_slowest => 100,
+      },
+      {
+        errors => 8.9e-05,
+        participant => "Log::ger-100k_log_trace",
+        rate => 61,
+        samples => 6,
+        time => 0.016,
+        vs_slowest => 100,
       },
     ],
     {
@@ -217,18 +225,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -237,7 +245,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3209.347,
+                                              speed                        => 3218.634,
                                               stepping                     => 7,
                                             },
                                             {
@@ -312,18 +320,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -332,7 +340,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "3257.300",
+                                              speed                        => "3221.850",
                                               stepping                     => 7,
                                             },
                                             {
@@ -407,18 +415,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -427,7 +435,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3142.261,
+                                              speed                        => 3210.308,
                                               stepping                     => 7,
                                             },
                                             {
@@ -502,18 +510,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -522,64 +530,66 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3100.363,
+                                              speed                        => 3201.794,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 143.751966953278,
+      "func.elapsed_time"              => 31.769749879837,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                           => "1.040",
+                                            "__PACKAGE__"                           => 1.041,
                                             "Bencher::Scenario::LogGer::NullOutput" => undef,
                                             "Benchmark::Dumb"                       => 0.111,
                                             "Devel::Platform::Info"                 => 0.16,
-                                            "Log::Any"                              => 1.049,
+                                            "Log::Any"                              => 1.707,
                                             "Log::Contextual"                       => 0.007001,
                                             "Log::Contextual::SimpleLogger"         => 0.007001,
+                                            "Log::Dispatch"                         => 2.65,
+                                            "Log::Dispatch::Null"                   => 2.65,
                                             "Log::Dispatchouli"                     => 2.015,
                                             "Log::Fast"                             => "v2.0.0",
                                             "Log::ger"                              => 0.023,
                                             "Log::ger::Plugin::MultilevelLog"       => 0.023,
-                                            "Log::ger::Plugin::OptAway"             => 0.005,
+                                            "Log::ger::Plugin::OptAway"             => 0.006,
                                             "Log::Log4perl"                         => 1.49,
                                             "Log::Log4perl::Tiny"                   => "1.4.0",
                                             "perl"                                  => "v5.26.0",
                                             "Sys::Info"                             => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 15]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 16]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "e15c0e5d1013f4fddebc4adcc93c7604",
-      "func.scenario_module_mtime"     => 1501852783,
-      "func.scenario_module_sha1sum"   => "8760dcc0d89761e2341a4926f7f6eb0391d846f5",
-      "func.scenario_module_sha256sum" => "1ddb4d9c4b215449754bda1a28ef12faccae5138b6f898a720c62621f1798782",
-      "func.time_end"                  => 1501853195.62431,
+      "func.scenario_module_md5sum"    => "2545aa76918d20d72bc07f68ab9e751f",
+      "func.scenario_module_mtime"     => 1545303314,
+      "func.scenario_module_sha1sum"   => "e8e8d813e5d3cb164adf45da30990b691a5b10eb",
+      "func.scenario_module_sha256sum" => "6fc798b7c6de437769f1c479d30b2445af82124cb7300cdd50119a891eb1db87",
+      "func.time_end"                  => 1545303619.95853,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1501853051.87234,
+      "func.time_start"                => 1545303588.18878,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s"],
       "table.fields"                   => [
