@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NumericLevel;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -9,19 +9,19 @@ our $results = [
     [
       {
         dataset    => "warn",
-        errors     => 5.8e-11,
-        rate       => 2290000,
-        samples    => 20,
-        time       => 436,
+        errors     => 2.5e-10,
+        rate       => 2060000,
+        samples    => 25,
+        time       => 484,
         vs_slowest => 1,
       },
       {
         dataset    => 10,
-        errors     => 2.5e-10,
-        rate       => 2480000,
-        samples    => 22,
-        time       => 404,
-        vs_slowest => 1.08,
+        errors     => 1.6e-09,
+        rate       => 2200000,
+        samples    => 21,
+        time       => 450,
+        vs_slowest => 1.1,
       },
     ],
     {
@@ -105,18 +105,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -125,7 +125,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3211.648,
+                                              speed                        => 3312.481,
                                               stepping                     => 7,
                                             },
                                             {
@@ -200,18 +200,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -220,7 +220,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3193.121,
+                                              speed                        => 3275.775,
                                               stepping                     => 7,
                                             },
                                             {
@@ -295,18 +295,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -315,7 +315,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3267.593,
+                                              speed                        => 3303.778,
                                               stepping                     => 7,
                                             },
                                             {
@@ -390,18 +390,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -410,14 +410,14 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3142.625,
+                                              speed                        => 3289.587,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0548899173736572,
+      "func.elapsed_time"              => 0.0495820045471191,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => "1.040",
+                                            "__PACKAGE__" => 1.041,
                                             "Bencher::Scenario::LogGer::NumericLevel" => undef,
                                             "Benchmark::Dumb" => 0.111,
                                             "Devel::Platform::Info" => 0.16,
@@ -429,24 +429,24 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0, 1]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -456,9 +456,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1501851634,
       "func.scenario_module_sha1sum"   => "278771b127381816b42d9f13ba18a9ceef40312a",
       "func.scenario_module_sha256sum" => "cd83a7931d9409b46d31ed8ffc2b982441ca840ce3d0ca2e5abf77a786dc813d",
-      "func.time_end"                  => 1501853195.86687,
+      "func.time_end"                  => 1545303620.2274,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1501853195.81198,
+      "func.time_start"                => 1545303620.17782,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ns"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
