@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -8,204 +8,204 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00021,
+        errors => 0.00035,
         participant => "init-with-FileWriteRotate",
-        rate => 18,
-        samples => 20,
-        time => 57,
+        rate => 21,
+        samples => 23,
+        time => 48,
         vs_slowest => 1,
       },
       {
-        errors => 8.2e-05,
+        errors => 0.00029,
         participant => "init-with-Syslog",
-        rate => 26,
+        rate => 29,
         samples => 20,
-        time => 38,
-        vs_slowest => 1.5,
+        time => 35,
+        vs_slowest => 1.4,
       },
       {
-        errors => 5.3e-05,
+        errors => 8.5e-05,
         participant => "init-with-LogAny",
-        rate => 42,
-        samples => 20,
-        time => 24,
+        rate => 50,
+        samples => 21,
+        time => 20,
         vs_slowest => 2.4,
       },
       {
-        errors => 7.2e-05,
+        errors => 0.00024,
         participant => "init-with-Composite",
-        rate => 47,
-        samples => 20,
-        time => 21,
-        vs_slowest => 2.7,
-      },
-      {
-        errors => 4.6e-05,
-        participant => "init-with-DirWriteRotate",
-        rate => 51,
+        rate => 50,
         samples => 20,
         time => 20,
-        vs_slowest => 2.9,
+        vs_slowest => 3,
       },
       {
-        errors => 7.4e-05,
-        participant => "init-with-ArrayRotate",
-        rate => 65,
-        samples => 21,
-        time => 15,
-        vs_slowest => 3.7,
-      },
-      {
-        errors => 6.7e-05,
-        participant => "init-with-Screen",
-        rate => 65,
+        errors => 7e-05,
+        participant => "init-with-DirWriteRotate",
+        rate => 57,
         samples => 20,
-        time => 15,
-        vs_slowest => 3.7,
+        time => 18,
+        vs_slowest => 2.8,
       },
       {
-        errors => 3.8e-05,
+        errors => 8.7e-05,
         participant => "init-with-File",
-        rate => 65,
+        rate => 70,
         samples => 20,
-        time => 15,
-        vs_slowest => 3.7,
+        time => 14,
+        vs_slowest => 3.4,
       },
       {
-        errors => 1.8e-05,
-        participant => "init-with-String",
-        rate => 65,
-        samples => 20,
-        time => 15,
-        vs_slowest => 3.7,
-      },
-      {
-        errors => 6.7e-05,
+        errors => 0.00015,
         participant => "init-with-Null",
-        rate => 66,
+        rate => 70,
         samples => 20,
-        time => 15,
-        vs_slowest => 3.7,
+        time => 10,
+        vs_slowest => 3,
       },
       {
-        errors => 3.9e-05,
+        errors => 0.00011,
         participant => "init-with-Array",
-        rate => 66,
+        rate => 75,
         samples => 20,
-        time => 15,
-        vs_slowest => 3.8,
+        time => 13,
+        vs_slowest => 3.6,
       },
       {
-        errors => 2.5e-05,
-        participant => "init-with-Callback",
-        rate => 67,
-        samples => 20,
-        time => 15,
-        vs_slowest => 3.8,
-      },
-      {
-        errors => 5.9e-05,
-        participant => "load-Screen",
+        errors => 5e-05,
+        participant => "init-with-ArrayRotate",
         rate => 76,
         samples => 20,
         time => 13,
-        vs_slowest => 4.3,
+        vs_slowest => 3.7,
       },
       {
-        errors => 4.7e-05,
-        participant => "load-Composite",
+        errors => 8.1e-05,
+        participant => "init-with-Screen",
+        rate => 76,
+        samples => 20,
+        time => 13,
+        vs_slowest => 3.7,
+      },
+      {
+        errors => 6.2e-05,
+        participant => "init-with-Callback",
+        rate => 76,
+        samples => 20,
+        time => 13,
+        vs_slowest => 3.7,
+      },
+      {
+        errors => 1.9e-05,
+        participant => "init-with-String",
+        rate => 79,
+        samples => 20,
+        time => 13,
+        vs_slowest => 3.8,
+      },
+      {
+        errors => 8.9e-05,
+        participant => "load-Screen",
+        rate => 82,
+        samples => 20,
+        time => 12,
+        vs_slowest => 4,
+      },
+      {
+        errors => 0.0001,
+        participant => "load-File",
         rate => 100,
         samples => 20,
-        time => 9.8,
+        time => 9,
+        vs_slowest => 5,
+      },
+      {
+        errors => 0.00012,
+        participant => "load-LogAny",
+        rate => 100,
+        samples => 20,
+        time => 9,
+        vs_slowest => 5,
+      },
+      {
+        errors => 2.7e-05,
+        participant => "load-Composite",
+        rate => 120,
+        samples => 20,
+        time => 8.6,
+        vs_slowest => 5.6,
+      },
+      {
+        errors => 7.6e-05,
+        participant => "load-FileWriteRotate",
+        rate => 120,
+        samples => 20,
+        time => 8.5,
+        vs_slowest => 5.7,
+      },
+      {
+        errors => 7.8e-05,
+        participant => "load-ArrayRotate",
+        rate => 120,
+        samples => 20,
+        time => 8.4,
         vs_slowest => 5.8,
       },
       {
-        errors => 7.4e-05,
-        participant => "load-LogAny",
-        rate => 110,
+        errors => 7.6e-05,
+        participant => "load-Callback",
+        rate => 120,
         samples => 20,
-        time => 9.2,
+        time => 8.3,
+        vs_slowest => 5.9,
+      },
+      {
+        errors => 2.7e-05,
+        participant => "load-Array",
+        rate => 130,
+        samples => 20,
+        time => 7.9,
         vs_slowest => 6.1,
       },
       {
-        errors => 4.4e-05,
-        participant => "load-Callback",
-        rate => 110,
-        samples => 20,
-        time => 9.2,
-        vs_slowest => 6.2,
-      },
-      {
-        errors => 5.8e-05,
-        participant => "load-String",
-        rate => 110,
-        samples => 20,
-        time => 9.1,
-        vs_slowest => 6.2,
-      },
-      {
-        errors => 5.4e-05,
-        participant => "load-Array",
-        rate => 110,
-        samples => 20,
-        time => 9.1,
-        vs_slowest => 6.2,
-      },
-      {
-        errors => 4.2e-05,
-        participant => "load-ArrayRotate",
-        rate => 110,
-        samples => 20,
-        time => 9.1,
-        vs_slowest => 6.2,
-      },
-      {
-        errors => 2.3e-05,
+        errors => 3.2e-05,
         participant => "load-Syslog",
-        rate => 110,
+        rate => 130,
         samples => 20,
-        time => 9.1,
+        time => 7.8,
         vs_slowest => 6.2,
       },
       {
-        errors => 6.8e-05,
-        participant => "load-FileWriteRotate",
-        rate => 110,
-        samples => 21,
-        time => 9.1,
+        errors => 1.8e-05,
+        participant => "load-String",
+        rate => 130,
+        samples => 20,
+        time => 7.8,
         vs_slowest => 6.2,
       },
       {
-        errors => 2.4e-05,
-        participant => "load-File",
-        rate => 110,
-        samples => 20,
-        time => 9,
-        vs_slowest => 6.3,
-      },
-      {
-        errors => 4.2e-05,
+        errors => 1.2e-05,
         participant => "load-DirWriteRotate",
-        rate => 110,
+        rate => 130,
         samples => 20,
-        time => 8.9,
+        time => 7.6,
         vs_slowest => 6.4,
       },
       {
-        errors => 3.6e-05,
+        errors => 5.7e-05,
         participant => "load-Null",
-        rate => 150,
-        samples => 20,
-        time => 6.5,
-        vs_slowest => 8.7,
-      },
-      {
-        errors => 4.4e-05,
-        participant => "baseline",
         rate => 170,
         samples => 20,
+        time => 6.1,
+        vs_slowest => 8,
+      },
+      {
+        errors => 8.2e-05,
+        participant => "baseline",
+        rate => 200,
+        samples => 20,
         time => 6,
-        vs_slowest => 9.4,
+        vs_slowest => 8,
       },
     ],
     {
@@ -289,18 +289,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -309,7 +309,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3294.355,
+                                              speed                        => 3293.371,
                                               stepping                     => 7,
                                             },
                                             {
@@ -384,18 +384,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -404,7 +404,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3227.753,
+                                              speed                        => 3290.722,
                                               stepping                     => 7,
                                             },
                                             {
@@ -479,18 +479,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -499,7 +499,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 3258.753,
+                                              speed                        => 3296.777,
                                               stepping                     => 7,
                                             },
                                             {
@@ -574,18 +574,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -594,28 +594,28 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3275.585,
+                                              speed                        => 3301.129,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 9.64052104949951,
+      "func.elapsed_time"              => 8.62850189208984,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                              => "1.040",
+                                            "__PACKAGE__"                              => 1.041,
                                             "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                             "Benchmark::Dumb"                          => 0.111,
                                             "Devel::Platform::Info"                    => 0.16,
-                                            "Log::ger::Output::Array"                  => 0.023,
+                                            "Log::ger::Output::Array"                  => 0.024,
                                             "Log::ger::Output::ArrayRotate"            => 0.001,
-                                            "Log::ger::Output::Callback"               => 0.002,
+                                            "Log::ger::Output::Callback"               => 0.003,
                                             "Log::ger::Output::Composite"              => 0.007,
                                             "Log::ger::Output::DirWriteRotate"         => 0.002,
                                             "Log::ger::Output::File"                   => 0.006,
                                             "Log::ger::Output::FileWriteRotate"        => 0.002,
                                             "Log::ger::Output::LogAny"                 => 0.006,
-                                            "Log::ger::Output::Null"                   => 0.023,
+                                            "Log::ger::Output::Null"                   => 0.024,
                                             "Log::ger::Output::Screen"                 => 0.007,
-                                            "Log::ger::Output::String"                 => 0.023,
+                                            "Log::ger::Output::String"                 => 0.024,
                                             "Log::ger::Output::Syslog"                 => 0.001,
                                             "perl"                                     => "v5.26.0",
                                             "Sys::Info"                                => 0.78,
@@ -624,24 +624,24 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 24]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -651,9 +651,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1501852763,
       "func.scenario_module_sha1sum"   => "d1cb23bd40993b0438d71bba57064482d531ded8",
       "func.scenario_module_sha256sum" => "a20a22b9dda21be3cd39583d0a92e817df9600c345417ee0a4c9587c52a7440c",
-      "func.time_end"                  => 1501853206.91214,
+      "func.time_end"                  => 1545303630.12967,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501853197.27162,
+      "func.time_start"                => 1545303621.50117,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
