@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Overhead;
 
-our $VERSION = 0.012; # VERSION
+our $VERSION = 0.013; # VERSION
 
 our $results = [
   [
@@ -8,192 +8,157 @@ our $results = [
     "OK",
     [
       {
-        code_overhead_time => 124,
-        errors => 0.00023,
+        code_overhead_time => 97.4,
+        errors => 8.2e-05,
         participant => "use Log::Dispatchouli;",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 4,
-        proc_size => 20,
         samples => 20,
-        time => 130,
+        time => 103,
         vs_slowest => 1,
       },
       {
-        code_overhead_time => 88,
-        errors => 0.00017,
-        participant => "use Log::Contextual qw(:log);",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
+        code_overhead_time => 94.4,
+        errors => 0.00011,
+        participant => "use Log::Dispatch; my \$null = Log::Dispatch->new(outputs=>[ [\"Nu",
         samples => 20,
-        time => 94,
+        time => 100,
+        vs_slowest => 1,
+      },
+      {
+        code_overhead_time => 89.6,
+        errors => 7.4e-05,
+        participant => "use Log::Dispatch;",
+        samples => 20,
+        time => 95.2,
+        vs_slowest => 1.08,
+      },
+      {
+        code_overhead_time => 71.4,
+        errors => 0.00015,
+        participant => "use Log::Contextual qw(:log);",
+        samples => 20,
+        time => 77,
         vs_slowest => 1.3,
       },
       {
-        code_overhead_time => 39,
-        errors => 0.00013,
+        code_overhead_time => 31.8,
+        errors => 2.6e-05,
         participant => "use Log::Log4perl;",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 3.9,
-        proc_size => 20,
         samples => 20,
-        time => 45,
-        vs_slowest => 2.8,
+        time => 37.4,
+        vs_slowest => 2.76,
       },
       {
-        code_overhead_time => 21,
-        errors => 7.9e-05,
+        code_overhead_time => 14.4,
+        errors => 0.00025,
         participant => "use Log::ger::App; use Log::ger;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 3.9,
-        proc_size => 20,
         samples => 20,
-        time => 27,
-        vs_slowest => 4.6,
+        time => 20,
+        vs_slowest => 4,
       },
       {
-        code_overhead_time => 19,
-        errors => 3.6e-05,
+        code_overhead_time => 15.4,
+        errors => 3.1e-05,
         participant => "use Log::Log4perl::Tiny;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
         samples => 20,
-        time => 25,
-        vs_slowest => 5.1,
+        time => 21,
+        vs_slowest => 4.9,
       },
       {
-        code_overhead_time => 13,
-        errors => 4.3e-05,
+        code_overhead_time => 14.4,
+        errors => 0.0002,
         participant => "use Log::ger::App;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 3.9,
-        proc_size => 20,
-        samples => 21,
-        time => 19,
-        vs_slowest => 6.7,
+        samples => 20,
+        time => 20,
+        vs_slowest => 6,
       },
       {
-        code_overhead_time => 12,
-        errors => 6.1e-05,
+        code_overhead_time => 10.4,
+        errors => 4e-05,
         participant => "use Log::ger::Like::Log4perl;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
         samples => 20,
-        time => 18,
+        time => 16,
+        vs_slowest => 6.3,
+      },
+      {
+        code_overhead_time => 9.4,
+        errors => 9.4e-05,
+        participant => "use Log::Any q(\$log);",
+        samples => 20,
+        time => 15,
         vs_slowest => 6.9,
       },
       {
-        code_overhead_time => 12,
-        errors => 7.3e-05,
-        participant => "use Log::Any q(\$log);",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 22,
-        time => 18,
-        vs_slowest => 7.1,
-      },
-      {
-        code_overhead_time => 11,
-        errors => 6.4e-05,
+        code_overhead_time => 8.4,
+        errors => 3.3e-05,
         participant => "use Log::Any;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 20,
-        time => 17,
-        vs_slowest => 7.6,
+        samples => 21,
+        time => 14,
+        vs_slowest => 7.2,
       },
       {
-        code_overhead_time => 7,
-        errors => 3.9e-05,
+        code_overhead_time => 7.4,
+        errors => 0.00012,
         participant => "use Log::ger::Output::Screen;",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 4,
-        proc_size => 20,
         samples => 20,
         time => 13,
-        vs_slowest => 9.5,
+        vs_slowest => 8.3,
       },
       {
-        code_overhead_time => 4,
-        errors => 2e-05,
+        code_overhead_time => 4.4,
+        errors => 0.00015,
         participant => "use Log::ger::Output::Composite;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 3.9,
-        proc_size => 20,
         samples => 20,
         time => 10,
-        vs_slowest => 13,
+        vs_slowest => 10,
       },
       {
-        code_overhead_time => 3.9,
-        errors => 2.5e-05,
+        code_overhead_time => 3.2,
+        errors => 2.8e-05,
         participant => "use Log::ger::Plugin::OptAway; use Log::ger;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 20,
-        time => 9.9,
-        vs_slowest => 13,
+        samples => 22,
+        time => 8.8,
+        vs_slowest => 12,
       },
       {
-        code_overhead_time => 1.4,
+        code_overhead_time => 0.9,
         errors => 3e-05,
-        participant => "use Log::ger::Like::LogAny;",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 3.9,
-        proc_size => 20,
-        samples => 20,
-        time => 7.4,
-        vs_slowest => 17,
-      },
-      {
-        code_overhead_time => 1,
-        errors => 7.2e-05,
-        participant => "use Log::ger; Log::ger->get_logger;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 20,
-        time => 7,
-        vs_slowest => 20,
-      },
-      {
-        code_overhead_time => 1,
-        errors => 7.5e-05,
-        participant => "use Log::ger;",
-        proc_private_dirty_size => 572,
-        proc_rss_size => 4,
-        proc_size => 20,
-        samples => 20,
-        time => 7,
-        vs_slowest => 20,
-      },
-      {
-        code_overhead_time => 1,
-        errors => 1.7e-05,
         participant => "use Log::ger ();",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 4,
-        proc_size => 20,
         samples => 20,
-        time => 7,
-        vs_slowest => 18,
+        time => 6.5,
+        vs_slowest => 16,
       },
       {
-        code_overhead_time => 0,
-        errors => 6.5e-05,
-        participant => "perl -e1 (baseline)",
-        proc_private_dirty_size => 568,
-        proc_rss_size => 4,
-        proc_size => 20,
+        code_overhead_time => 0.4,
+        errors => 7.4e-05,
+        participant => "use Log::ger; Log::ger->get_logger;",
         samples => 20,
         time => 6,
         vs_slowest => 20,
       },
+      {
+        code_overhead_time => 0.800000000000001,
+        errors => 1.5e-05,
+        participant => "use Log::ger::Like::LogAny;",
+        samples => 21,
+        time => 6.4,
+        vs_slowest => 16,
+      },
+      {
+        code_overhead_time => 0.7,
+        errors => 3.6e-05,
+        participant => "use Log::ger;",
+        samples => 20,
+        time => 6.3,
+        vs_slowest => 16,
+      },
+      {
+        code_overhead_time => 0,
+        errors => 3.6e-05,
+        participant => "perl -e1 (baseline)",
+        samples => 20,
+        time => 5.6,
+        vs_slowest => 18,
+      },
     ],
     {
       "func.bencher_args"              => {
@@ -276,18 +241,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -296,7 +261,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3159.457,
+                                              speed                        => 3242.095,
                                               stepping                     => 7,
                                             },
                                             {
@@ -371,18 +336,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -391,7 +356,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3223.878,
+                                              speed                        => 3255.529,
                                               stepping                     => 7,
                                             },
                                             {
@@ -466,18 +431,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -486,7 +451,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "3205.230",
+                                              speed                        => 2713.067,
                                               stepping                     => 7,
                                             },
                                             {
@@ -561,18 +526,18 @@ our $results = [
                                                                                 "xsave",
                                                                                 "avx",
                                                                                 "lahf_lm",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -581,22 +546,24 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3212.375,
+                                              speed                        => 3153.924,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 11.7200911045074,
+      "func.elapsed_time"              => 15.2736229896545,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                         => "1.040",
+                                            "__PACKAGE__"                         => 1.041,
                                             "Bencher::Scenario::LogGer::Overhead" => undef,
                                             "Benchmark::Dumb"                     => 0.111,
                                             "Devel::Platform::Info"               => 0.16,
-                                            "Log::Any"                            => 1.049,
+                                            "Log::Any"                            => 1.707,
                                             "Log::Contextual"                     => 0.007001,
+                                            "Log::Dispatch"                       => 2.65,
+                                            "Log::Dispatch::Null"                 => 2.65,
                                             "Log::Dispatchouli"                   => 2.015,
                                             "Log::ger"                            => 0.023,
-                                            "Log::ger::App"                       => 0.003,
+                                            "Log::ger::App"                       => 0.009,
                                             "Log::ger::Layout::Pattern"           => 0.001,
                                             "Log::ger::Output"                    => 0.023,
                                             "Log::Log4perl"                       => 1.49,
@@ -605,56 +572,43 @@ our $results = [
                                             "Sys::Info"                           => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 17]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 19]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "sonya",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-4.8.0-53-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "4.8.0-53-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 18.2,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.2 Sonya \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.2 Sonya\nRelease:\t18.2\nCodename:\tsonya",
+                                                          "uname -a"        => "Linux builder 4.8.0-53-generic #56~16.04.1-Ubuntu SMP Tue May 16 01:18:56 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "4.8.0-53-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Overhead",
-      "func.scenario_module_md5sum"    => "0edc3d4a26f5e2516bdf1ad69c8c206d",
-      "func.scenario_module_mtime"     => 1501851050,
-      "func.scenario_module_sha1sum"   => "1865868844b4870a6c50857d2865074b6a056d14",
-      "func.scenario_module_sha256sum" => "8470af634e0518da7fd37e1beecf5507d1b5188dffe51727d748505336531ee0",
-      "func.time_end"                  => 1501853223.58396,
+      "func.scenario_module_md5sum"    => "c1109d32fb348d903c9767f1a6d47c34",
+      "func.scenario_module_mtime"     => 1545302243,
+      "func.scenario_module_sha1sum"   => "ee9305bf048c7bd064f0c6444a71822528ba64e0",
+      "func.scenario_module_sha256sum" => "77da734fec62910d35386d2c942b32b2febaa8c5b6f1d3c6534bcda67eb6ceaf",
+      "func.time_end"                  => 1545303649.16709,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1501853211.86386,
-      "table.field_aligns"             => [
-                                            "left",
-                                            "left",
-                                            "left",
-                                            "left",
-                                            "number",
-                                            "number",
-                                            "number",
-                                            "number",
-                                            "number",
-                                          ],
-      "table.field_units"              => [undef, "kB", "MB", "MB", "ms", "ms"],
+      "func.time_start"                => 1545303633.89346,
+      "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
+      "table.field_units"              => [undef, "ms", "ms"],
       "table.fields"                   => [
                                             "participant",
-                                            "proc_private_dirty_size",
-                                            "proc_rss_size",
-                                            "proc_size",
                                             "time",
                                             "code_overhead_time",
                                             "vs_slowest",
